==> ser-0.8.10_src.tar.gz: ser-0.8.10/parser/case_call.h <==
/*
 * $Id: case_call.h,v 1.3 2002/09/19 12:23:55 jku Rel $
 *
 * Call-ID header field parser macros
 *
 * Copyright (C) 2001-2003 Fhg Fokus
 *
 * This file is part of ser, a free SIP server.
 *
 * ser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * ser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef CASE_CALL_H
#define CASE_CALL_H


#define ID_CASE                      \
     switch(val) {                   \
     case __ID1_:                    \
	     hdr->type = HDR_CALLID; \
	     hdr->name.len = 7;      \
	     *(p + 3) = '\0';        \
	     return (p + 4);         \
	                             \
     case __ID2_:                    \
	     hdr->type = HDR_CALLID; \
	     p += 4;                 \
	     goto dc_end;            \
     }


#define Call_CASE      \
     p += 4;           \
     val = READ(p);    \
     ID_CASE;          \
                       \
     val = unify(val); \
     ID_CASE;          \
                       \
     goto other;


#endif /* CASE_CALL_H */

==> ser-0.8.14_src.tar.gz: ser-0.8.14/parser/case_call.h <==
/* 
 * $Id: case_call.h,v 1.6 2003/02/28 14:12:26 jiri Exp $ 
 *
 * Call-ID Header Name Parsing Macros
 *
 * Copyright (C) 2001-2003 Fhg Fokus
 *
 * This file is part of ser, a free SIP server.
 *
 * ser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * ser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * History:
 * ----------
 * 2003-02-28 scratchpad compatibility abandoned (jiri)
 * 2003-01-27 next baby-step to removing ZT - PRESERVE_ZT (jiri)
 */


#ifndef CASE_CALL_H
#define CASE_CALL_H

#include "../comp_defs.h"

#define ID_CASE                      \
     switch(LOWER_DWORD(val)) {      \
     case __id1_:                    \
	     hdr->type = HDR_CALLID; \
	     hdr->name.len = 7;      \
	     return (p + 4);         \
	                             \
     case __id2_:                    \
	     hdr->type = HDR_CALLID; \
	     p += 4;                 \
	     goto dc_end;            \
     }


#define call_CASE      \
     p += 4;           \
     val = READ(p);    \
     ID_CASE;          \
     goto other;


#endif /* CASE_CALL_H */
